@@ -22,7 +22,7 @@
 #'   Finally, note that this function does \strong{not} check whether the specified constraints are feasible (e.g. whether
 #'   the implied constrained model would be stationary or have positive definite error term covariance matrices).
 #' @return A list with class "hypotest" containing the test results and arguments used to calculate the test.
-#' @seealso \code{\link{LR_test}}, \code{\link{fitGSMVAR}}, \code{\link{GSMVAR}}, \code{\link{diagnostic_plot}},
+#' @seealso \code{\link{LR_test}}, \code{\link{Rao_test}}, \code{\link{fitGSMVAR}}, \code{\link{GSMVAR}}, \code{\link{diagnostic_plot}},
 #'  \code{\link{profile_logliks}}, \code{\link{quantile_residual_tests}}, \code{\link{cond_moment_plot}}
 #' @inherit in_paramspace_int references
 #' @examples
@@ -71,10 +71,13 @@ Wald_test <- function(gsmvar, A, c, custom_h=NULL) {
     print(paste("Failed to invert Hessian matrix:", e))
     return(NA)
   })
-  if(anyNA(inv_Hess)) stop("Couldn't invert Hessian matrix of the log-likelihood function. This might happen when the mixing weights are very close to zero for some regime (if so, reduce the redundant regime from the model).")
+  if(anyNA(inv_Hess)) stop("Couldn't invert Hessian matrix of the log-likelihood function.
+                           This might happen when the mixing weights are very close to zero for some regime
+                           (if so, reduce the redundant regime from the model).")
 
   # Calculate the test statistic
-  test_stat <- as.numeric(crossprod(A%*%params - c, solve(-tcrossprod(A%*%inv_Hess, A), A%*%params - c))) # t(A%*%params - c)%*%solve(-A%*%inv_Hess%*%t(A))%*%(A%*%params - c)
+  # t(A%*%params - c)%*%solve(-A%*%inv_Hess%*%t(A))%*%(A%*%params - c)
+  test_stat <- as.numeric(crossprod(A%*%params - c, solve(-tcrossprod(A%*%inv_Hess, A), A%*%params - c)))
 
   # Calculate the p-value
   df <- nrow(A)
@@ -119,7 +122,7 @@ Wald_test <- function(gsmvar, A, c, custom_h=NULL) {
 #'   of the unconstrained and constrained parameter spaces.
 #'
 #'   Note that this function does \strong{not} verify that the two models are actually nested.
-#' @seealso \code{\link{Wald_test}}, \code{\link{fitGSMVAR}}, \code{\link{GSMVAR}}, \code{\link{diagnostic_plot}},
+#' @seealso \code{\link{Wald_test}}, \code{\link{Rao_test}}, \code{\link{fitGSMVAR}}, \code{\link{GSMVAR}}, \code{\link{diagnostic_plot}},
 #'  \code{\link{profile_logliks}}, \code{\link{quantile_residual_tests}}, \code{\link{cond_moment_plot}}
 #' @inherit in_paramspace_int references
 #' @inherit Wald_test return
@@ -178,3 +181,108 @@ LR_test <- function(gsmvar1, gsmvar2) {
 }
 
 
+
+#' @title Perform Rao's score test for a GSMVAR model
+#'
+#' @description \code{Rao_test} performs Rao's score test for a GSMVAR model
+#'
+#' @param gsmvar an object of class \code{'gsmvar'} generated by \code{fitGSMVAR} or \code{GSMVAR}, containing
+#'   the model specified by the null hypothesis (i.e., \strong{the constrained model}).
+#' @details Tests the constraints imposed in the model given in the argument \code{GSMVAR}.
+#'  This implementation uses the outer product of gradients approximation in the test statistic.
+#' @seealso \code{\link{LR_test}}, \code{\link{Wald_test}}, \code{\link{fitGSMVAR}}, \code{\link{GSMVAR}}, \code{\link{diagnostic_plot}},
+#'  \code{\link{profile_logliks}}
+#' @inherit Wald_test references return
+#' @examples
+#' \donttest{
+#' ## These are long running examples that use parallel computing!
+#' ## The below examples take around 30 seconds to run.
+#'
+#' # Structural GMVAR(2, 2), d=2 model with recursive identification
+#' # with the AR matrices  restricted to be the identical across the regimes:
+#' W22 <- matrix(c(1, NA, 0, 1), nrow=2, byrow=FALSE)
+#' C_mat <- rbind(diag(2*2^2), diag(2*2^2))
+#' fit22sc <- fitGSMVAR(gdpdef, p=2, M=2, constraints=C_mat,
+#'                      structural_pars=list(W=W22), ncalls=1, seeds=1)
+#'
+#' # Test the null:
+#' Rao_test(fit22sc)
+#' }
+#' @export
+
+Rao_test <- function(gsmvar) {
+  gsmvar <- gmvar_to_gsmvar(gsmvar) # Backward compatibility
+  stopifnot(!is.null(gsmvar$data))
+
+  # Obtain the unconstrained model by expanding the contraints:
+  p <- gsmvar$model$p
+  M <- gsmvar$model$M
+  d <- gsmvar$model$d
+  params <- gsmvar$params
+  model <- gsmvar$model$model
+  constraints <- gsmvar$model$constraints
+  same_means <- gsmvar$model$same_means
+  parametrization <- gsmvar$model$parametrization
+  structural_pars <- gsmvar$model$structural_pars
+  conditional <- gsmvar$model$conditional
+  params <- reform_constrained_pars(p=p, M=M, d=d, params=params, model=model, constraints=constraints,
+                                    same_means=same_means, structural_pars=structural_pars)
+  structural_pars <- get_unconstrained_structural_pars(structural_pars=structural_pars)
+  new_gsmvar <- GSMVAR(data=gsmvar$data, p=p, M=M, d=d, params=params, conditional=conditional,
+                       parametrization=parametrization, constraints=NULL, same_means=NULL,
+                       structural_pars=structural_pars, calc_std_errors=FALSE, stat_tol=gsmvar$num_tols$stat_tol,
+                       posdef_tol=gsmvar$num_tols$posdef_tol, df_tol=gsmvar$num_tols$df_tol)
+
+  # Calculate the gradient:
+  Grad <- tryCatch(get_gradient(new_gsmvar),
+                   error=function(e) {
+                     print(paste("Failed to calculate the gradient matrix:", e))
+                     return(NA)})
+  if(anyNA(Grad)) {
+    stop("Couldn't calculate gradient. Check that the estimates are not very close to the boundary of the parameter space.")
+  }
+
+  # Gradients of the terms l_t
+  foo <- function(x, which_obs=1) {
+    # Log-likelihood function as a function of the parameter
+    loglikelihood_int(data=new_gsmvar$data, p=p, M=M, params=x, conditional=conditional,
+                      parametrization=parametrization, constraints=NULL, same_means=NULL,
+                      structural_pars=structural_pars, stat_tol=gsmvar$num_tols$stat_tol,
+                      posdef_tol=gsmvar$num_tols$posdef_tol, df_tol=gsmvar$num_tols$df_tol,
+                      to_return="terms", minval=NA)[which_obs]
+  }
+  T_obs <- nrow(new_gsmvar$data) - new_gsmvar$model$p
+  outer_prods <- array(dim=c(length(Grad), length(Grad), T_obs))
+  # Calculate the outer product of the gradient for each observation, i.e., gradient each term l_t, t=1,...,T:
+  for(i1 in 1:T_obs) {
+    grad0 <- calc_gradient(x=new_gsmvar$params, fn=foo, which_obs=i1)
+    outer_prods[, , i1] <- tcrossprod(grad0)
+  }
+  OPG <- apply(outer_prods, 1:2, sum)
+
+  # Invert the OPG matrix
+  inv_OPG <- tryCatch(solve(OPG), error=function(e) {
+    print(paste("Failed to invert the outer product of gradients matrix:", e))
+    return(NA)
+  })
+
+  if(anyNA(inv_OPG)) stop("Couldn't invert the outer product of gradients matrix of the log-likelihood function. Make sure the
+                           estimates are ok, e.g., with the function 'profile_logliks'.")
+
+  # Calculate the test statistic
+  test_stat <- as.numeric(crossprod(Grad, inv_OPG%*%Grad))
+
+  # Calculate the p-value
+  df <- length(new_gsmvar$params) - length(gsmvar$params) # The number of constraints
+  p_value <- pchisq(test_stat, df=df, lower.tail=FALSE)
+
+  # Return
+  structure(list(gsmvar=gsmvar,
+                 gsmvar_unconstrained=new_gsmvar,
+                 df=df,
+                 test_stat=test_stat,
+                 df=df,
+                 p_value=p_value,
+                 type="Rao test"),
+            class="hypotest")
+}
