@@ -46,24 +46,24 @@ test_that("GIRF works correctly", {
   expect_equal(unname(girf4$girf_res[[1]]$point_est[,2]), c(3.017544, 1.250930, 1.511186), tolerance=1e-4)
   expect_equal(unname(girf4$girf_res[[1]]$conf_ints[1, 2, ]), c(1.000000, 3.017544, 0.000000, 0.000000), tolerance=1e-4)
 
-  expect_equal(unname(girf5$girf_res[[1]]$point_est[3,]), c(1.669579e-01, -7.251490e-02, 2.065481e-05, -2.065481e-05), tolerance=1e-4)
-  expect_equal(unname(girf5$girf_res[[2]]$point_est[1,]), c(-0.9514335, -0.1542835, 0.0000000, 0.0000000), tolerance=1e-4)
-  expect_equal(unname(girf5$girf_res[[2]]$conf_ints[3, , 2]), c(-0.4840127, -0.4551930, -0.1477824, -0.1189627), tolerance=1e-4)
-  expect_equal(unname(girf5$girf_res[[1]]$conf_ints[1, 1, ]), c(-0.7153089, -0.1987499, 0.0000000, 0.0000000), tolerance=1e-4)
+  expect_equal(unname(girf5$girf_res[[1]]$point_est[3,]), c(-0.0020754868, 0.0683132253, -0.0009629171, 0.0009629171), tolerance=1e-4)
+  expect_equal(unname(girf5$girf_res[[2]]$point_est[1,]), c(-0.8900453, 0.0309581, 0.0000000, 0.0000000 ), tolerance=1e-4)
+  expect_equal(unname(girf5$girf_res[[2]]$conf_ints[3, , 2]), c(-0.054190858, -0.049303411, 0.002829363, 0.007716811), tolerance=1e-4)
+  expect_equal(unname(girf5$girf_res[[1]]$conf_ints[1, 1, ]), c(-0.05380848, -0.16236944, 0.00000000, 0.00000000), tolerance=1e-4)
 
-  expect_equal(unname(girf6$girf_res[[1]]$point_est[1,]), c(0.4467698, 0.1979680), tolerance=1e-4)
-  expect_equal(unname(girf6$girf_res[[1]]$point_est[2,]), c(0.2507398, 0.3915768), tolerance=1e-4)
-  expect_equal(unname(girf6$girf_res[[1]]$conf_ints[2, 2, ]), c(0.2507398, 0.3915768), tolerance=1e-4)
+  expect_equal(unname(girf6$girf_res[[1]]$point_est[1,]), c(0.06994922, 0.21107483), tolerance=1e-4)
+  expect_equal(unname(girf6$girf_res[[1]]$point_est[2,]), c(-0.01627362, 0.29857639), tolerance=1e-4)
+  expect_equal(unname(girf6$girf_res[[1]]$conf_ints[2, 2, ]), c(-0.01627362, 0.29857639), tolerance=1e-4)
 
-  expect_equal(unname(girf7$girf_res[[1]]$point_est[11,]), c(0.032326891, 0.240915655, -0.001879026, 0.001879026), tolerance=1e-4)
-  expect_equal(unname(girf7$girf_res[[2]]$point_est[11,]), c(-3.5349067, -0.4698592, -3.1878321, 3.1878321), tolerance=1e-4)
-  expect_equal(unname(girf7$girf_res[[1]]$conf_ints[10, 2, ]), c(-0.5697602, -0.0763127, -0.2645382, -0.2644381), tolerance=1e-4)
-  expect_equal(unname(girf7$girf_res[[2]]$conf_ints[10, 4, ]), c(4.016071, 3.616466, 4.504059, 20.080489), tolerance=1e-4)
+  expect_equal(unname(girf7$girf_res[[1]]$point_est[11,]), c(0.085809980, 0.040115100, 0.003851488, -0.003851488), tolerance=1e-4)
+  expect_equal(unname(girf7$girf_res[[2]]$point_est[11,]), c(-2.149830, 3.544420, -6.878577, 6.878577), tolerance=1e-4)
+  expect_equal(unname(girf7$girf_res[[1]]$conf_ints[10, 2, ]), c(-0.0661237, -0.1219151, -0.1729235, -0.1751087), tolerance=1e-4)
+  expect_equal(unname(girf7$girf_res[[2]]$conf_ints[10, 4, ]), c(1.26414556, 15.37729027, -0.07734892, 9.60187218), tolerance=1e-4)
 
-  expect_equal(unname(girf8$girf_res[[1]]$point_est[11,]), c(-0.04691326, 0.07027594, 0.11717142, -0.11717142), tolerance=1e-4)
-  expect_equal(unname(girf8$girf_res[[2]]$point_est[11,]), c(-0.05080895, 0.03214937, 0.09800529, -0.09800529), tolerance=1e-4)
-  expect_equal(unname(girf8$girf_res[[1]]$conf_ints[10, 2, ]), c(-0.3768587, -0.1879175, -0.2536318, -0.3432418), tolerance=1e-4)
-  expect_equal(unname(girf8$girf_res[[2]]$conf_ints[10, 4, ]), c(0.2626703, 0.3669083, 0.5024262, 0.1319560), tolerance=1e-4)
+  expect_equal(unname(girf8$girf_res[[1]]$point_est[11,]), c(-0.1277645, 0.1080400, -0.2497952, 0.2497952), tolerance=1e-4)
+  expect_equal(unname(girf8$girf_res[[2]]$point_est[11,]), c(0.03559951, -0.08510815, 0.11788692, -0.11788692), tolerance=1e-4)
+  expect_equal(unname(girf8$girf_res[[1]]$conf_ints[10, 2, ]), c(-0.447233736, -0.011134464, -0.543594759, -0.009362696), tolerance=1e-4)
+  expect_equal(unname(girf8$girf_res[[2]]$conf_ints[10, 4, ]), c(0.310809556, -0.015914113, 0.239282102, -0.007601098), tolerance=1e-4)
 })
 
 
@@ -94,10 +94,10 @@ test_that("GFEVD works correctly", {
   expect_equal(unname(gfevd3$gfevd_res[1, , 2]), c(0.993477615, 0.006522385), tolerance=1e-3)
   expect_equal(unname(gfevd3$gfevd_res[5, , 3]), c(0.2543561, 0.7456439), tolerance=1e-3)
   expect_equal(unname(gfevd3$gfevd_res[4, , 4]), c(0.7643379, 0.2356621), tolerance=1e-3)
-  expect_equal(c(unname(gfevd4$gfevd_res[3, , ])), c(0.003385848, 0.996614152, 0.970176207, 0.029823793), tolerance=1e-3)
-  expect_equal(c(unname(gfevd4$gfevd_res[2, , ])), c(0.003247969, 0.996752031, 0.978639508, 0.021360492), tolerance=1e-3)
-  expect_equal(c(unname(gfevd5$gfevd_res[3, , ])), c(0.06959060, 0.93040940, 0.96216059, 0.03783941), tolerance=1e-3)
-  expect_equal(c(unname(gfevd5$gfevd_res[1, , ])), c(0.02707136, 0.97292864, 0.97663429, 0.02336571), tolerance=1e-3)
+  expect_equal(c(unname(gfevd4$gfevd_res[3, , ])), c(0.01107482, 0.98892518, 0.98476182, 0.01523818), tolerance=1e-3)
+  expect_equal(c(unname(gfevd4$gfevd_res[2, , ])), c(0.01155714, 0.98844286, 0.98837229, 0.01162771), tolerance=1e-3)
+  expect_equal(c(unname(gfevd5$gfevd_res[3, , ])), c(0.006679063, 0.993320937, 0.985635052, 0.014364948), tolerance=1e-3)
+  expect_equal(c(unname(gfevd5$gfevd_res[1, , ])), c(0.006968765, 0.993031235, 0.981418598, 0.018581402), tolerance=1e-3)
 
   expect_equal(c(unname(gfevd6$gfevd_res[1, , 1:2])), c(0.092954461, 0.907045539, 0.998705168, 0.001294832), tolerance=1e-3)
   expect_equal(c(unname(gfevd6$gfevd_res[3, , ])), c(0.0894120535, 0.9105879465, 0.9990029740, 0.0009970260, 0.0007465000,
